Verification
============

Z3 and angr backends, CEGAR orchestrator, verification types, and harness
builder.

.. automodule:: verification
   :members:
   :show-inheritance:

.. automodule:: verification.types
   :members:
   :show-inheritance:

.. automodule:: verification.backend
   :members:
   :show-inheritance:

.. automodule:: verification.backends.z3_backend
   :members:
   :show-inheritance:

.. automodule:: verification.backends.angr_docker
   :members:
   :show-inheritance:

.. automodule:: verification.backends.mock
   :members:
   :show-inheritance:

.. automodule:: verification.orchestrator
   :members:
   :show-inheritance:

.. automodule:: verification.harness.builder
   :members:
   :show-inheritance:
